﻿using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace Falcon.ModelSP
{
    /// <summary>
    /// 执行存储过程接口
    /// </summary>
    public interface IFalconSPRuner
    {
        /// <summary>
        /// 通过数据库上下文执行无返回值的存储过程
        /// </summary>
        /// <typeparam name="TPrarmType">参数类型</typeparam>
        /// <param name="db">数据上下文</param>
        /// <param name="data">参数数据</param>
        int RunSP<TPrarmType>(DbContext db,TPrarmType data);

        /// <summary>
        /// 通过数据库上下文执行存储过程，并返回查询结果
        /// </summary>
        /// <typeparam name="TPrarmType">参数类型</typeparam>
        /// <typeparam name="TResultType">返回结果项类型</typeparam>
        /// <param name="db">数据上下文</param>
        /// <param name="data">参数数据</param>
        IEnumerable<TResultType> RunSP<TPrarmType, TResultType>(DbContext db,TPrarmType data) where TResultType : class, new();
        
        /// <summary>
        /// 通过数据库上下文执行存储过程，并返回查询结果
        /// </summary>
        /// <typeparam name="TPrarmType">参数类型</typeparam>
        /// <typeparam name="TResultType">返回结果项类型</typeparam>
        /// <param name="db">数据上下文</param>
        /// <param name="data">参数数据</param>
        IEnumerable<TResultType> RunSPQuery<TPrarmType, TResultType>(DbContext db,TPrarmType data) where TResultType : class, new();

        /// <summary>
        /// 根据模型定义参数执行存储过程进行查询，参数类型必须定义FalconSPReturnTypeAttribute特性
        /// </summary>
        /// <typeparam name="TPrarmType">存储过程参数类型</typeparam>
        /// <param name="db">数据上下文</param>
        /// <param name="data">存储过程参数</param>
        /// <returns>返回类型枚举FalconSPReturnTypeAttribute定义的类型枚举。</returns>
        IEnumerable<object> RunSPQuery<TPrarmType>(DbContext db,TPrarmType data);
    }
}
